## Introduction à Seaborn

---

### Qu'est-ce que Seaborn ?

[Seaborn](https://seaborn.pydata.org/) est une bibliothèque de visualisation de données en Python basée sur Matplotlib. Elle offre une interface de haut niveau pour créer des graphiques attrayants et informatifs. Elle est particulièrement utile pour visualiser des données complexes, comme celles provenant de DataFrames pandas.

---

### Afficher des diagrammes avec Seaborn

Seaborn propose plusieurs types de diagrammes, comme les nuages de points, les histogrammes, les diagrammes à barres, etc. Chaque type de diagramme est adapté à un type particulier de données et permet d'en extraire différents types d'informations.

---

#### Afficher un nuage de points

Un nuage de points est un type de diagramme qui permet de visualiser la relation entre deux variables continues. Avec Seaborn, vous pouvez créer un nuage de points en utilisant la fonction `scatterplot()` :

```{.python .numberLines}
import seaborn as sns

# Supposons que nous ayons un DataFrame pandas df avec deux colonnes 'x' et 'y'
sns.scatterplot(x='x', y='y', data=df)
```

---

#### Afficher un histogramme avec facettes

Un histogramme est un type de diagramme qui permet de visualiser la distribution d'une variable continue. Avec Seaborn, vous pouvez créer un histogramme avec facettes (c'est-à-dire, plusieurs histogrammes pour différentes catégories de données) en utilisant la fonction `FacetGrid()` :

```{.python .numberLines}
# Supposons que nous ayons un DataFrame pandas df avec une colonne 'x' et une colonne catégorielle 'cat'
g = sns.FacetGrid(df, col='cat')
g.map(sns.histplot, 'x')
```

---

#### Afficher un histogramme en barres avec facettes

Un histogramme en barres est un type de diagramme qui permet de visualiser la distribution d'une variable catégorielle. Avec Seaborn, vous pouvez créer un histogramme en barres avec facettes en utilisant les fonctions `FacetGrid()` et `barplot()` :

```{.python .numberLines}
# Supposons que nous ayons un DataFrame pandas df avec une colonne 'x' et deux colonnes catégorielles 'cat1' et 'cat2'
g = sns.FacetGrid(df, col='cat1')
g.map(sns.barplot, 'cat2', 'x')
```

---

### Configurer le thème des graphiques Seaborn

Seaborn offre plusieurs options pour personnaliser l'apparence de vos graphiques.

---

#### Styles des graphiques

Seaborn propose cinq thèmes prédéfinis : `darkgrid`, `whitegrid`, `dark`, `white`, et `ticks`. Vous pouvez les appliquer en utilisant la fonction `set_style()` :

```{.python .numberLines}
sns.set_style('whitegrid')
```

---

#### Définir des palettes de couleurs

Seaborn offre plusieurs palettes de couleurs pour personnaliser l'apparence de vos graphiques. Vous pouvez les utiliser en passant le nom de la palette à la fonction `color_palette()` :

```{.python .numberLines}
sns.set_palette(sns.color_palette('Blues'))
```

Ainsi, Seaborn vous permet de créer facilement des graphiques attrayants et informatifs en Python.
